#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from __future__ import annotations

from pathlib import Path

"""
Adapted from shared/system to avoid including ssa-workspaces in pex
"""


class JSONSerializable:
    def __json__(self, request=None) -> dict:
        """
        Allows this object to be converted to JSON

        :param request: this parameter is the active Pyramid request, if applicable (None otherwise)
        :return: a dictionary which can be converted to JSON using json.dump
        """
        pass

    @classmethod
    def from_json(cls, json: dict) -> any:
        pass


class AbstractTextFile(JSONSerializable):
    """
    Abstract text file is exactly that, an abstract concept of what a file is, to be
    returned from various non-filesystem places.
    """

    def __init__(self, filename: str, content: str):
        self.filename, self.content = filename, content

    def write_to(self, directory: Path):
        (directory / self.filename).write_text(self.content)

    @classmethod
    def from_path(cls, path: Path) -> AbstractTextFile:
        return cls(path.name, path.read_text())
