"""update std_calibration workflow templates to use PEXes

Revision ID: 2b6e18877c8e
Revises: 23e9b7724ad8
Create Date: 2021-05-17 16:24:42.854708

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "2b6e18877c8e"
down_revision = "23e9b7724ad8"
branch_labels = None
depends_on = None


def upgrade():
    submit_file_contents = """executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh

getenv = True

queue
"""
    op.execute(
        f"UPDATE workflow_templates SET content = E'{submit_file_contents}' WHERE filename = 'std_calibration.condor'"
    )

    script_contents = """#!/bin/sh
SCRIPTS_DIR=$(pycapo -q edu.nrao.workspaces.ProcessingSettings.scriptLocation)

export PATH=$PATH:${SCRIPTS_DIR}

./framework.sh -d .
cd rawdata/
./productfetcher --product-locator $1
cd ../
./casa_envoy --standard-cal $3 $4
./deliver-cipl.sh ${PWD##*/}
"""
    op.execute(f"UPDATE workflow_templates SET content = E'{script_contents}' WHERE filename = 'std_calibration.sh'")


def downgrade():
    op.execute(
        """
        UPDATE workflow_templates
        SET content =
        E'#!/bin/sh
        SCRIPTS_DIR=$(pycapo -q edu.nrao.workspaces.ProcessingSettings.scriptLocation)

        export PATH=$PATH:${SCRIPTS_DIR}

        framework.sh -d .
        cd rawdata/
        datafetcher --product-locator $1
        cd ../
        casa_envoy --standard-cal $3 $4
        deliver-cipl.sh ${PWD##*/}'
        WHERE filename = 'std_calibration.sh'
        """
    )

    op.execute(
        """
        UPDATE workflow_templates
        SET content = E'executable = std_calibration.sh
        arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml
        error = calibration.err
        log = condor.log


        queue' WHERE filename = 'std_calibration.condor'
        """
    )
